caellion-python-commons: caellion.pycommons.serializers.datetime_serializer Namespace Reference

caellion-python-commons

Classes
caellion.pycommons.serializers.datetime_serializer Namespace Reference

This module provides various serializers for datetime.datetime object. More...

## Classes
class | DateTimeIsoTimeSerializer
| Implementation of DateTime serializer, using IsoTime as a serialized standard. More...
class | DateTimeUnixMillisSerializer
| Implementation of DateTime serializer, using Unix-epoch based timestamp with millisecond precision as serialized format. More...
class | DateTimeUnixMicrosSerializer
| Implementation of DateTime serializer, using Unix-epoch based timestamp with microsecond precision as serialized format. More...
class | DateTimeUnixSerializer
| Implementation of DateTime serializer, using Unix-epoch based timestamp with second precision as serialized format. More...

## Detailed Description

This module provides various serializers for datetime.datetime object.